bioimg.ingestion

client.bioimg.ingestion

Functions

Name Description
ingest The function ingests microscopy images into TileDB arrays

ingest

client.bioimg.ingestion.ingest(
    source,
    output,
    config,
    *args,
    acn='',
    taskgraph_name=None,
    num_batches=None,
    threads=0,
    resources=None,
    ingest_resources=None,
    compute=True,
    register=True,
    mode=Mode.BATCH,
    namespace,
    verbose=False,
    exclude_metadata=None,
    converter=None,
    output_ext='',
    tile_scale=128,
    timeout=86400,
    **kwargs,
)

The function ingests microscopy images into TileDB arrays

:param source: uri / iterable of uris of input files. If the uri points to a directory of files make sure it ends with a trailing ‘/’ :param output: uri / iterable of uris of output files. If the uri points to a directory of files make sure it ends with a trailing ‘/’ :param config: dict configuration to pass on tiledb.VFS for the source’s resolution :param acn: Access Credentials Name (ACN) registered in TileDB Cloud (ARN type) :param taskgraph_name: Optional name for taskgraph, defaults to None :param num_batches: Number of graph nodes to spawn. Performs it sequentially if default, defaults to 1 :param threads: Number of threads for node side multiprocessing, defaults to 0 :param resources: configuration for node specs e.g. {“cpu”: “8”, “memory”: “4Gi”}, defaults to None :param ingest_resources: configuration for node specs e.g. {“cpu”: “8”, “memory”: “4Gi”}. This parameter is intended to be used with the as_batch() wrapper and with the TileDB UI ingest endpoint. It defaults to None and will be superseded by the resources parameter described above. :param compute: When True the DAG returned will be computed inside the function otherwise DAG will only be returned. :param register: When True the ingested images are also being registered under the namespace in which were ingested. Should be False when tiledb uris are given as destination paths, registration node is merged with the ingestion stage. :param mode: By default runs Mode.Batch :param namespace: The namespace where the DAG will run :param verbose: verbose logging, defaults to False :param exclude_metadata: An optional argument that specifies how to transform the original metadata. It can be one of the following: * A callable (function, method, etc.) that takes an OME-XML string and returns it as a string, while removing some of the original metadata and excluding them from being ingested. * A boolean value: * True: Indicates a specific built-in transformation should be applied * False: Indicates no transformation should be applied * None: Indicates no transformation should be applied (same as False). :param converter: The converter to be used for the image ingestion, when None the default TIFF converter is used. Available converters are one of the (“tiff”, “zarr”, “osd”). :param output_ext: extension for the output images in tiledb :param tile_scale: The scaling factor applied to each tile during I/O. Larger scale factors will result in less I/O operations. :param access_credentials_name: [TBDeprecated] Access Credentials Name (ACN) registered in TileDB Cloud (ARN type) if acn is not set. :param dest_config: dict configuration to pass on tiledb.VFS for the destination’s resolution :param reader: The selected reader backend implementation either “experimental” or “production”. Default[“production”] :param timeout: Duration (sec) ingestion DAG allowed to execute before timeout. The default is 86400 seconds (24 hours).