dashboard

client.dashboard

Functions

Name Description
panel_dashboard Start a Panel server with the provided app and return an iframe that enables

panel_dashboard

client.dashboard.panel_dashboard(
    app,
    *,
    full_screen_link=True,
    title='Dashboard - TileDB',
    verbose=False,
    vh_delta=70,
)

Start a Panel server with the provided app and return an iframe that enables viewing the app in Voila. This wrapper avoids issues with reactive Panel apps in Voila.

:param app: The Panel app to serve. :param full_screen_link: Include a link to the full screen view, defaults to True. :param title: Title for the Panel server, defaults to “Dashboard - TileDB”. :param verbose: Enable verbose logging, defaults to False. :param vh_delta: The vertical height delta for the iframe in px. This value is subtracted from 100vh to set the height of the iframe. :return: A Panel HTML pane containing an iframe that displays the app.