taskgraphs.registration

client.taskgraphs.registration

Classes

Name Description
TaskGraphError Raised when a task graph can not be registered, retrieved, or executed.
TaskGraphRegistrar Registers a task graph to a path or to a folder.

TaskGraphError

client.taskgraphs.registration.TaskGraphError()

Raised when a task graph can not be registered, retrieved, or executed.

TaskGraphRegistrar

client.taskgraphs.registration.TaskGraphRegistrar()

Registers a task graph to a path or to a folder.

The asset creation pattern is implemented in the base class.

Methods

Name Description
call_api_method Adapt arguments for the underlying API method.
call_api_method
client.taskgraphs.registration.TaskGraphRegistrar.call_api_method(
    workspace,
    teamspace,
    path,
    request,
)

Adapt arguments for the underlying API method.

Functions

Name Description
load Retrieves a task graph from the server.
register Registers the graph constructed by the TaskGraphBuilder.
update Updates a registered task graph.

load

client.taskgraphs.registration.load(path, *, teamspace=None)

Retrieves a task graph from the server.

Parameters

Name Type Description Default
path str or object The TileDB path at which the object is registered. May be a path relative to a teamspace, an Asset instance, or an absolute “tiledb” URI. required
teamspace Teamspace or str The teamspace to which the object is registered, specified by object or id. If not provided, the path parameter is queried for a teamspace id. None

Returns

Name Type Description
dict A representation of a task graph.

register

client.taskgraphs.registration.register(graph, path, *, teamspace=None)

Registers the graph constructed by the TaskGraphBuilder.

Parameters

Name Type Description Default
graph TaskGraphBuilder The graph to be registered. required
path str or object The TileDB path at which the object is to be registered. May be a path relative to a teamspace, a Folder or Asset instance, or an absolute “tiledb” URI. If the path to a folder is provided, the name of the function will be appended to form a full asset path. required
teamspace Teamspace or str The teamspace to which the object will be registered, specified by object or id. If not provided, the path parameter is queried for a teamspace id. None

update

client.taskgraphs.registration.update(graph, path, *, teamspace=None)

Updates a registered task graph.

Parameters

Name Type Description Default
graph TaskGraphBuilder The replacement graph. required
path str or object The TileDB path at which the object is registered. May be a path relative to a teamspace, an Asset instance, or an absolute “tiledb” URI. required
teamspace Teamspace or str The teamspace to which the object is registered, specified by object or id. If not provided, the path parameter is queried for a teamspace id. None