utilities.consolidate
client.utilities.consolidate
Functions
| Name | Description |
|---|---|
| consolidate | Consolidate fragments |
| consolidate_and_vacuum | Consolidate and vacuum commits and fragment metadata, with an option to |
| consolidate_fragments | Consolidate fragments in an array. |
| group_fragments | Get a list of fragment info objects, optionally grouping fragments that have the |
consolidate
client.utilities.consolidate.consolidate(
array_uri,
fragments,
*,
config=None,
max_fragment_size=MAX_FRAGMENT_SIZE_BYTES,
)Consolidate fragments
:param array_uri: array URI :param fragments: list of fragments :param config: config dictionary, defaults to None :param max_fragment_size: max size of consolidated fragments, defaults to MAX_FRAGMENT_SIZE_BYTES
consolidate_and_vacuum
client.utilities.consolidate.consolidate_and_vacuum(
array_uri,
*,
config=None,
vacuum_fragments=False,
)Consolidate and vacuum commits and fragment metadata, with an option to vacuum fragments as the first step.
:param array_uri: array URI :param config: config dictionary, defaults to None :param vacuum_fragments: vacuum fragments first, defaults to False
consolidate_fragments
client.utilities.consolidate.consolidate_fragments(
array_uri,
*,
acn=None,
config=None,
group_by_first_dim=False,
graph=None,
dependencies=None,
consolidate_resources=None,
workspace=None,
max_fragment_size=MAX_FRAGMENT_SIZE_BYTES,
image_name='default',
)Consolidate fragments in an array.
If group_by_first_dim is True, fragments with the same value for the first dimension will be consolidated together. Otherwise, all fragments will be consolidated together.
If graph is provided, the consolidation task nodes will be submitted to the graph. If dependencies is provided, the consolidation nodes will depend on the nodes in the list.
If graph is not provided, a new graph will be created and submitted to TileDB Cloud.
:param array_uri: array URI :param acn: Access Credentials Name (ACN) registered in TileDB Cloud (ARN type), defaults to None :param config: config dictionary, defaults to None :param group_by_first_dim: group fragment by first dimension, defaults to True :param graph: graph to submit nodes to, defaults to None :param dependencies: list of nodes in the graph to depend on, defaults to None :param consolidate_resources: resources for the consolidate node, defaults to None :param workspace: TileDB Cloud workspace, defaults to the user’s default workspace :param max_fragment_size: max size of consolidated fragments, defaults to MAX_FRAGMENT_SIZE_BYTES :param image_name: udf image name to use, useful for testing beta features
group_fragments
client.utilities.consolidate.group_fragments(
array_uri,
*,
config=None,
group_by_first_dim=True,
)Get a list of fragment info objects, optionally grouping fragments that have the same value for the first dimension.
:param array_uri: array URI :param config: config dictionary, defaults to None :param group_by_first_dim: group by first dimension, defaults to True :return: list of lists of fragment info objects