workflows.workflow

client.workflows.workflow

Functions for working with TileDB workflows.

Functions

Name Description
create Create a TileDB workflow template asset, which includes the members:

create

client.workflows.workflow.create(
    tiledb_uri,
    language,
    name,
    version,
    main,
    tarfile_path,
    parameter_schema_dict={},
    input_schema_dict={},
)

Create a TileDB workflow template asset, which includes the members:

- README.md: A description of the workflow template.
- workflow.tgz: The workflow template contents in a tarfile.
- parameters.json: The workflow parameter schema as a JSON file.
- input.json: The workflow input schema as a JSON file.

and metadata:

- dataset_type: "workflow"
- language: The workflow language.
- name: The name of the workflow.
- version: The workflow version.
- main: The name of the main file in the workflow.

:param tiledb_uri: URI where the workflow will be registered and stored :param language: workflow language :param name: name of the workflow :param version: version of the workflow :param main: name of the main file in the workflow :param tarfile_path: path to the tarfile containing the workflow :param parameter_schema_dict: workflow parameter spec, defaults to {} :param input_schema_dict: input spec, defaults to {} :return: None