bioimg.exportation
client.bioimg.exportation
Functions
| Name | Description |
|---|---|
| export | The function exports microscopy images from TileDB arrays |
export
client.bioimg.exportation.export(
source,
output,
*args,
access_credentials_name,
config=None,
taskgraph_name=None,
num_batches=None,
resources=None,
compute=True,
mode=Mode.BATCH,
namespace=None,
verbose=False,
output_ext='tiff',
**kwargs,
)The function exports microscopy images from TileDB arrays
:param source: uri / iterable of uris of input files If the uri points to a directory of files make sure it ends with a trailing ‘/’ :param output: uri / iterable of uris of input files. If the uri points to a directory of files make sure it ends with a trailing ‘/’ :param config: dict configuration to pass credentials of the destination :param taskgraph_name: Optional name for taskgraph, defaults to None :param num_batches: Number of graph nodes to spawn. Performs it sequentially if default, defaults to 1 :param threads: Number of threads for node side multiprocessing, defaults to 8 :param resources: configuration for node specs e.g. {“cpu”: “8”, “memory”: “4Gi”}, defaults to None :param compute: When True the DAG returned will be computed inside the function otherwise DAG will only be returned. :param mode: By default runs Mode.Batch :param namespace: The namespace where the DAG will run :param verbose: verbose logging, defaults to False :param access_credentials_name: Access Credentials Name (ACN) registered in TileDB Cloud (ARN type) :param output_ext: extension for the output images in tiledb