compute.delayed
client.compute.delayed
Classes
| Name | Description |
|---|---|
| Delayed | Serverless Python function execution as a future. |
| DelayedArrayUDF | Serverless Array UDF called with the |
| DelayedBase | Base Delayed interface class |
| DelayedMultiArrayUDF | Serverless Multi-Array UDF called with the |
| DelayedSQL | Serverless SQL query on a registered Array called with the |
Delayed
client.compute.delayed.Delayed(
func_exec,
*args,
local=False,
mode=Mode.REALTIME,
**kwargs,
)Serverless Python function execution as a future.
Extends DelayedBase
DelayedArrayUDF
client.compute.delayed.DelayedArrayUDF(uri, func_exec, *args, **kwargs)Serverless Array UDF called with the Delayed API
Extends DelayedBase
DelayedBase
client.compute.delayed.DelayedBase(
func,
*args,
name=None,
dag=None,
local_mode=False,
mode=Mode.REALTIME,
**kwargs,
)Base Delayed interface class
Methods
| Name | Description |
|---|---|
| all | Run a list of Delayed object all in parallel |
| compute | Starts execution of all Delayed tasks associated with this node. |
| visualize | Build and render a tree diagram of the DAG. |
all
client.compute.delayed.DelayedBase.all(futures, workspace=None)Run a list of Delayed object all in parallel :param futures: list of Delayed objects to run :param workspace: optional workspace to run all tasks in :return: list of results in order of futures
compute
client.compute.delayed.DelayedBase.compute(name=None, max_workers=None)Starts execution of all Delayed tasks associated with this node.
:param workspace: The workspace to execute tasks under, if different than the user’s default. :param name: An optional name to identify the task graph in logs. :return: results
visualize
client.compute.delayed.DelayedBase.visualize(
notebook=True,
auto_update=True,
force_plotly=False,
)Build and render a tree diagram of the DAG. :param notebook: Is the visualization inside a jupyter notebook? If so we’ll use a widget :param auto_update: Should the diagram be auto updated with each status change :param force_plotly: Force the use of plotly graphs instead of TileDB Plot Widget :return: returns plotly figure
DelayedMultiArrayUDF
client.compute.delayed.DelayedMultiArrayUDF(func, array_list, *args, **kwargs)Serverless Multi-Array UDF called with the Delayed API
Extends DelayedBase
DelayedSQL
client.compute.delayed.DelayedSQL(*args, **kwargs)Serverless SQL query on a registered Array called with the Delayed API
Extends DelayedBase