A teamspace is a container for assets and folders of assets. It will be backed by a unique cloud storage location and may be mounted as a directory in Notebooks and UDFs.
The TileDB web UI is the primary tool for managing teamspaces, but some functionality is available via this module.
Please note that this function may recursively deletes the teamspace’s assets and their object storage.
Parameters
Name
Type
Description
Default
teamspace
Teamspace or str
The teamspace to delete, identified by name or id.
required
delete_assets
bool
If True, the teamspace’s assets will be deregistered and deleted from the underlying storage (e.g., S3). If False, the entity’s assets will be deregistered, but remain in the underlying storage. Default: False.
This function can filter teamspaces based on the user’s membership and control the sorting of the results.
Parameters
Name
Type
Description
Default
memberships
bool
If True, returns teamspaces the user is a member of. If False, returns public teamspaces in the workspace that the user is NOT a member of. If not provided (default), the API’s default behavior is used, which is typically to return all teamspaces the user has access to.
None
order_by
str
The field to order the results by. Defaults to ‘created_at’. Valid values include ‘name’, ‘created_at’, ‘updated_at’.
None
order
str
The sorting direction. Defaults to ‘desc’. Valid values are ‘asc’, ‘desc’.
None
Returns
Name
Type
Description
list[Teamspace]
A list of Teamspace objects.
Raises
Name
Type
Description
TeamspacesError
If the teamspaces listing request failed.
Examples
List all teamspaces you are a member of
>>> my_teamspaces = teamspaces.list_teamspaces(memberships=True)>>> [ts.name for ts in my_teamspaces]["my-first-teamspace"]
List public teamspaces you are NOT a member of, ordered by name