vcf.utils
client.vcf.utils
Functions
| Name | Description |
|---|---|
| create_index_file | Create a VCF index file in the current working directory. |
| find_index | Find the index file for a VCF file or None if not found. |
| get_record_count | Return the record count in a VCF file. |
| get_sample_name | Returns the sample name in a VCF file. |
| is_bgzipped | Returns True if the VCF file is bgzipped. |
| sort_and_bgzip | Sort and bgzip a VCF file storing the result in the tmp space. |
create_index_file
client.vcf.utils.create_index_file(vcf_uri)Create a VCF index file in the current working directory.
:param vcf_uri: URI of the VCF file :return: index file name
find_index
client.vcf.utils.find_index(vcf_uri)Find the index file for a VCF file or None if not found.
:param vcf_uri: URI of the VCF file :return: URI of the index file
get_record_count
client.vcf.utils.get_record_count(vcf_uri, index_uri)Return the record count in a VCF file.
:param vcf_uri: URI of the VCF file :param index_uri: URI of the VCF index file :return: record count or None if there is an error
get_sample_name
client.vcf.utils.get_sample_name(vcf_uri)Returns the sample name in a VCF file.
If there are multiple samples, return a comma-separated list of sample names.
:param vcf_uri: URI of the VCF file :return: sample name
is_bgzipped
client.vcf.utils.is_bgzipped(vcf_uri)Returns True if the VCF file is bgzipped.
:param vcf_uri: URI of the VCF file :return: True if the VCF file is bgzipped
sort_and_bgzip
client.vcf.utils.sort_and_bgzip(vcf_uri, *, tmp_space='.')Sort and bgzip a VCF file storing the result in the tmp space.
:param vcf_uri: URI of the VCF file :param tmp_space: tmp space URI, defaults to the current directory :return: URI of bgzipped VCF